==> discover-5.5.5.tar.xz: discover-5.5.5/libdiscover/backends/ApplicationBackend/tests/NotifierTest.cpp <==
/***************************************************************************
 *   Copyright © 2015 Harald Sitter <sitter@kde.org>                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#include "NotifierTest.h"

#include <QTest>

#include <ApplicationNotifier.h>

QTEST_MAIN( NotifierTest )

NotifierTest::NotifierTest()
{
}

NotifierTest::~NotifierTest()
{
}

void NotifierTest::testInit()
{
    // Ensure init order is correct and we don't run into nullptr exceptions on
    // initialization.
    ApplicationNotifier app(this);
    app.metaObject()->invokeMethod(&app, "recheckSystemUpdateNeeded");
}

==> discover-5.7.3.tar.xz: discover-5.7.3/libdiscover/backends/ApplicationBackend/tests/NotifierTest.cpp <==
/***************************************************************************
 *   Copyright © 2015 Harald Sitter <sitter@kde.org>                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#include "NotifierTest.h"

#include <QTest>

#include <ApplicationNotifier.h>

QTEST_MAIN( NotifierTest )

NotifierTest::NotifierTest()
{
}

NotifierTest::~NotifierTest() = default;

void NotifierTest::testInit()
{
    // Ensure init order is correct and we don't run into nullptr exceptions on
    // initialization.
    ApplicationNotifier app(this);
    app.metaObject()->invokeMethod(&app, "recheckSystemUpdateNeeded");
}
